@@ -1,9 +1,3 @@
-#define NO_XSLOCKS
-#define PERL_NO_GET_CONTEXT
-
-#include "EXTERN.h"
-#include "perl.h"
-#include "XSUB.h"
 #include "ppport.h"
 #include <time.h>
 #include <stdlib.h>
